@@ -34,34 +34,28 @@
  */
 static GbWidget gbwidget;
 
-/* These are the special children of the widget. */
-static gchar *CListTitle = "CList:title";
-
 static gchar *Mode = "GtkCList::selection_mode";
 static gchar *Titles = "GtkCList::show_titles";
 static gchar *Shadow = "GtkCList::shadow_type";
 
 /* This is only used for loading & saving - it isn't displayed in the property
    editor. */
-static gchar *Cols = "GtkCList::columns";
+static gchar *Cols = "GtkCList::n_columns";
 static gchar *ColumnWidths = "GtkCList::column_widths";
 
 static const gchar *GbModeChoices[] =
-{"Single", "Browse", "Multiple",
- "Extended", NULL};
+{"Single", "Browse", "Multiple", NULL};
 static const gint GbModeValues[] =
 {
   GTK_SELECTION_SINGLE,
   GTK_SELECTION_BROWSE,
-  GTK_SELECTION_MULTIPLE,
-  GTK_SELECTION_EXTENDED
+  GTK_SELECTION_MULTIPLE
 };
 static const gchar *GbModeSymbols[] =
 {
   "GTK_SELECTION_SINGLE",
   "GTK_SELECTION_BROWSE",
-  "GTK_SELECTION_MULTIPLE",
-  "GTK_SELECTION_EXTENDED"
+  "GTK_SELECTION_MULTIPLE"
 };
 
 static const gchar *GbShadowChoices[] =
@@ -147,7 +141,8 @@ show_clist_dialog (GbWidgetNewData * data)
   GtkObject *adjustment;
 
   dialog = glade_util_create_dialog (_("New columned list"), data->parent,
-				     on_clist_dialog_ok, data, &vbox);
+				     GTK_SIGNAL_FUNC (on_clist_dialog_ok),
+				     data, &vbox);
   gtk_signal_connect (GTK_OBJECT (dialog), "destroy",
 		      GTK_SIGNAL_FUNC (on_clist_dialog_destroy), data);
 
@@ -222,7 +217,7 @@ new_label (GtkWidget * parent)
 
   label = gb_widget_new ("GtkLabel", parent);
   g_return_val_if_fail (label != NULL, NULL);
-  gb_widget_set_child_name (label, CListTitle);
+  gb_widget_set_child_name (label, GladeChildCListTitle);
   return label;
 }
 
@@ -235,7 +230,7 @@ new_unnamed_label (GtkWidget * parent)
   label = gb_widget_new_full ("GtkLabel", FALSE, parent, NULL, 0, 0, NULL,
 			      GB_CREATING, NULL);
   g_return_val_if_fail (label != NULL, NULL);
-  gb_widget_set_child_name (label, CListTitle);
+  gb_widget_set_child_name (label, GladeChildCListTitle);
   return label;
 }
 
@@ -414,30 +409,25 @@ gb_clist_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 void
 gb_clist_add_child (GtkWidget *widget, GtkWidget *child, GbWidgetSetArgData *data)
 {
-  gchar *child_name = load_get_value (data, "child_name");
+  /* We store the last column title read in 'last_child' */
+  gint col = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
+						   "last_child"));
 
-  if (child_name && (!strcmp (child_name, CListTitle)))
-    {
-      /* We store the last column title read in 'last_child' */
-      gint col = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
-                                                       "last_child"));
+  if (col >= GTK_CLIST (widget)->columns) {
+    g_warning ("Too many column title widgets for GtkCList - skipping");
+    return;
+  }
 
-      gtk_clist_set_column_widget (GTK_CLIST (widget), col, child);
-      gtk_object_set_data (GTK_OBJECT (widget), "last_child",
-                           GINT_TO_POINTER (col + 1));
+  gtk_clist_set_column_widget (GTK_CLIST (widget), col, child);
+  gtk_object_set_data (GTK_OBJECT (widget), "last_child",
+		       GINT_TO_POINTER (col + 1));
 
-      /* We need to add signals to the clist button, just in case the
-         title widget has no window and so doesn't get signals itself.
-         Since Clist always creates 1 button initially, the signals would
-         be added to this button in gb_widget_new, so we could skip it,
-         but it doesn't hurt. */
-      editor_add_mouse_signals_to_existing (GTK_CLIST (widget)->column[col].button);
-    }
-  else
-    {
-      g_warning ("Adding unknown child to a GtkCList");
-      gtk_container_add (GTK_CONTAINER (widget), child);
-    }
+  /* We need to add signals to the clist button, just in case the
+     title widget has no window and so doesn't get signals itself.
+     Since Clist always creates 1 button initially, the signals would
+     be added to this button in gb_widget_new, so we could skip it,
+     but it doesn't hurt. */
+  editor_add_mouse_signals_to_existing (GTK_CLIST (widget)->column[col].button);
 }
 
 
@@ -515,7 +505,7 @@ gb_clist_write_add_child_source (GtkWidget * parent,
   child_name = gb_widget_get_child_name (child);
 
   /* See if this is a title widget. */
-  if (child_name && (!strcmp (child_name, CListTitle)))
+  if (child_name && (!strcmp (child_name, GladeChildCListTitle)))
     {
       /* We store the last column title written in 'last_child' */
       gint col = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (parent),
@@ -538,19 +528,19 @@ gb_clist_write_add_child_source (GtkWidget * parent,
 
 
 static gboolean
-gb_clist_emission_hook (GtkObject *object,
-			guint signal_id,
-			guint n_params,
-			GtkArg *params,
-			gpointer data)
+gb_clist_emission_hook (GSignalInvocationHint  *ihint,
+			guint			n_param_values,
+			const GValue	       *param_values,
+			gpointer		data)
 {
-  GtkObject *hadjustment, *vadjustment;
+  GtkObject *object, *hadjustment, *vadjustment;
   GtkObject *old_hadjustment, *old_vadjustment;
 
+  object = g_value_get_object (param_values);
   g_return_val_if_fail (GTK_IS_CLIST (object), FALSE);
 
-  hadjustment = GTK_VALUE_OBJECT (params[0]);
-  vadjustment = GTK_VALUE_OBJECT (params[1]);
+  hadjustment = g_value_get_object (param_values + 1);
+  vadjustment = g_value_get_object (param_values + 2);
 
   old_hadjustment = gtk_object_get_data (object, "scrollhadjustment");
   if (hadjustment != old_hadjustment)
@@ -589,14 +579,15 @@ gb_clist_init ()
   GtkWidgetClass *klass;
 
   /* Initialise the GTK type */
-  gtk_clist_get_type ();
+  volatile GtkType type;
+  type = gtk_clist_get_type ();
 
   /* Add a signal emission hook so we can connect signal handlers to the
      scrollbar adjustments to redraw the clist when necessary. This will also
      work for subclasses of GtkCList. */
   klass = gtk_type_class (gtk_clist_get_type ());
-  gtk_signal_add_emission_hook (klass->set_scroll_adjustments_signal,
-				gb_clist_emission_hook, NULL);
+  g_signal_add_emission_hook (klass->set_scroll_adjustments_signal, 0,
+			      gb_clist_emission_hook, NULL, NULL);
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct (&gbwidget);
