@@ -36,6 +36,7 @@
  */
 static GbWidget gbwidget;
 
+/* Size is not saved to the XML. */
 static const gchar *Size = "HBox|GtkBox::size";
 static const gchar *Homogeneous = "HBox|GtkBox::homogeneous";
 static const gchar *Spacing = "HBox|GtkBox::spacing";
@@ -44,7 +45,7 @@ static const gchar *Spacing = "HBox|GtkBox::spacing";
 static const gchar *GbPadding = "GtkBoxChild::padding";
 static const gchar *GbExpand = "GtkBoxChild::expand";
 static const gchar *GbFill = "GtkBoxChild::fill";
-static const gchar *GbPack = "GtkBoxChild::pack";
+static const gchar *GbPack = "GtkBoxChild::pack_type";
 
 /* This is only used internally - it isn't save in the XML. */
 static const gchar *GbPosition = "GtkBoxChild::position";
@@ -96,7 +97,8 @@ show_hbox_dialog (GbWidgetNewData * data)
   GtkObject *adjustment;
 
   dialog = glade_util_create_dialog (_("New horizontal box"), data->parent,
-				     on_hbox_dialog_ok, data, &vbox);
+				     GTK_SIGNAL_FUNC (on_hbox_dialog_ok),
+				     data, &vbox);
   gtk_signal_connect (GTK_OBJECT (dialog), "destroy",
 		      GTK_SIGNAL_FUNC (on_hbox_dialog_destroy), data);
 
@@ -340,7 +342,7 @@ gb_box_get_child_properties (GtkWidget *widget, GtkWidget *child,
   GtkPackType pack_type;
 
   if (data->action == GB_SAVING)
-    save_start_tag (data, "child");
+    save_start_tag (data, "packing");
 
   if (data->action == GB_SHOWING)
     {
@@ -368,7 +370,7 @@ gb_box_get_child_properties (GtkWidget *widget, GtkWidget *child,
     }
 
   if (data->action == GB_SAVING)
-    save_end_tag (data, "child");
+    save_end_tag (data, "packing");
 }
 
 
@@ -445,13 +447,13 @@ gb_box_create_popup_menu (GtkWidget * widget, GbWidgetCreateMenuData * data)
 
   menuitem = gtk_menu_item_new_with_label (_("Insert Before"));
   gtk_widget_show (menuitem);
-  gtk_menu_append (GTK_MENU (data->menu), menuitem);
+  gtk_container_add (GTK_CONTAINER (data->menu), menuitem);
   gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 		      GTK_SIGNAL_FUNC (gb_box_insert_before), data->child);
 
   menuitem = gtk_menu_item_new_with_label (_("Insert After"));
   gtk_widget_show (menuitem);
-  gtk_menu_append (GTK_MENU (data->menu), menuitem);
+  gtk_container_add (GTK_CONTAINER (data->menu), menuitem);
   gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 		      GTK_SIGNAL_FUNC (gb_box_insert_after), data->child);
 }
@@ -551,7 +553,8 @@ GbWidget *
 gb_hbox_init ()
 {
   /* Initialise the GTK type */
-  gtk_hbox_get_type ();
+  volatile GtkType type;
+  type = gtk_hbox_get_type ();
 
   /* Initialize the GbWidget structure */
   gb_widget_init_struct (&gbwidget);
